<?php 

class SelectHourMin {

  private $scope;
  private $label;
  private $iterator;
  private $minutes;
  private $begin;
  private $end;
  private $colon;
  private $point;

  public function __construct($entry) {
 
    if (isset($entry)) {
      $this->scope    = $entry->scope;
      $this->label    = $entry->label;
      $this->iterator = $entry->iterator;
      $this->entryNow = $entry->entryNow;
      $this->minutes  = explode (",",$entry->minList);
      list($this->begin, $this->end) = explode (",",$entry->hourRange);

      $this->colon = "";
      $this->point = "";
      if ($entry->format == 'time') {
        $this->colon = "<span style=font-weight:800;float:left;display:inline;background:white;>:</span>";
      }  
      else if ($entry->format == 'duration') {
        $this->point = "&#8228;";
        
      }
  
      $this->postMessages = "";
      if (null !== $entry->listeners) {
        $listeners = explode(",", $entry->listeners);
        for ($i=0; $i<count($listeners); $i++) {
          $this->postMessages .= "listener" . $listeners[$i] . "(msgContent); ";
        }
      }    
    }
  }
  
  public function outputLayout() {

    $layout = "
<label for='tab$this->scope'>$this->label<br>

<table style='height:28px;border: 1px solid grey;'>
  <tr>
    <td>  
      <select id='hour$this->scope' name='hour$this->scope'
        style='height:18px;width:43px;direction:rtl;border:none;display:inline;padding-top:3px;'>
    ";
    for ($i=$this->begin; $i<$this->end; $i++) {
      $inner = sprintf("%02d", $i);
      $layout .= "
        <option value=$inner>$inner</option>
      ";
    }
  
    $layout .= "
      </select>   
    </td>
    <td>
      $this->colon
    </td>
    <td>
      <select id='min$this->scope' name='min$this->scope'
        style='height:18px;width:45px;border:none;display:inline;padding-top:3px;'>
	";
	
    for ($i=0; $i<count($this->minutes); $i++) {
      $selAttr = "";
      if ($this->minutes[$i] == $this->minValue)
        $selAttr = "selected";

      $inner = $this->minutes[$i];
      $layout .= "
        <option value=$inner $selAttr>$this->point$inner</option>
      ";
    }
  
    $layout .= "
      </select>
    </td>
  </tr>
</table>
</label>
  ";  

    return $layout;
  }

  public function outputScript() {
    $script = "


// Set current time on entry`    
$(document).ready(function() {

  delimiter$this->scope = ('$this->point' == '') ? ':' : '.';
  if ($this->entryNow) { 

    var d = new Date();

    var minutes = d.getMinutes();
    var hours = d.getHours();

    var m = (((minutes + 7.5)/15 | 0) * 15) % 60;
    var h = ((((minutes/105) + .5) | 0) + hours) % 24;
    var now = String('0' + h).slice(-2) + ':' + String('0' + m).slice(-2);

    var msgContent = [];
    msgContent.$this->scope = [now , '', 'formentry'];
    $this->postMessages
  } 
});  

// Minute dropdown changes  
$('#min$this->scope').on('change', function() {
  var refRowIds = ['00','00'];
  var hour = $('#hour$this->scope').val();
  var min = $(this).val();
  var msgContent = [];
  msgContent.$this->scope = [hour + delimiter$this->scope + min,delimiter$this->scope, 'formentry'];
  $this->postMessages
  $this->refreshList 
});

// Hour dropdown changes  
$('#hour$this->scope').on('change', function() {
  var refRowIds = ['00','00'];
  var hour = $(this).val();
  var min =  $('#min$this->scope').val();
  var msgContent = [];
  msgContent.$this->scope = [hour + delimiter$this->scope + min,delimiter$this->scope, 'formentry'];
  $this->postMessages
  $this->refreshList 
});

// db value changes    
function set$this->scope$this->iterator (dbValue, dbText, source) {
  var duration = String('0' + dbValue).slice(-5);
  var hours = String(duration.substring(0,2));
  var minutes = duration.substring(3,5);
  $('#hour$this->scope option[value='+hours+']').prop('selected',true);
  $('#min$this->scope option[value='+minutes+']').prop('selected',true);
}

multiFunction['$this->scope'] = {
  set$this->scope$this->iterator: set$this->scope$this->iterator
};  

    ";
  
    return $script;
  }
}  


?>